Index: src/sas/sasgui/guiframe/CategoryInstaller.py
===================================================================
--- src/sas/sasgui/guiframe/CategoryInstaller.py	(revision 212bfc297ca102b648c949f030d3d06a4c569fa3)
+++ src/sas/sasgui/guiframe/CategoryInstaller.py	(revision ddbac6633a1e7ec42b99bb39f46b9889ccf26084)
@@ -123,5 +123,6 @@
         compile it and install
         :param homefile: Override the default home directory
-        :param model_list: List of model names except customized models
+        :param model_list: List of model names except those in Plugin Models
+               which are user supplied.
         """
         _model_dict = { model.name: model for model in model_list}
Index: src/sas/sasgui/perspectives/calculator/pyconsole.py
===================================================================
--- src/sas/sasgui/perspectives/calculator/pyconsole.py	(revision d472e86b1c34df53a9ab5a44426b8256aaa39d4d)
+++ src/sas/sasgui/perspectives/calculator/pyconsole.py	(revision ddbac6633a1e7ec42b99bb39f46b9889ccf26084)
@@ -302,5 +302,5 @@
         success = show_model_output(self, fname)
 
-        # Update custom model list in fitpage combobox
+        # Update plugin model list in fitpage combobox
         if success and self._manager != None and self.panel != None:
             self._manager.set_edit_menu_helper(self.parent)
Index: src/sas/sasgui/perspectives/fitting/fitting.py
===================================================================
--- src/sas/sasgui/perspectives/fitting/fitting.py	(revision e92a35222de59b469e74be44064685ec4edc7c19)
+++ src/sas/sasgui/perspectives/fitting/fitting.py	(revision ddbac6633a1e7ec42b99bb39f46b9889ccf26084)
@@ -1964,5 +1964,6 @@
                 ## then kill itself but cannot.  Paul Kienzle came up with
                 ## this fix to prevent threads from stepping on each other
-                ## which was causing a simple custom model to crash Sasview.
+                ## which was causing a simple custom plugin model to crash
+                ##Sasview.
                 ## We still don't know why the fit sometimes lauched a second
                 ## thread -- something which should also be investigated.

Index: src/sas/sasgui/perspectives/calculator/model_editor.py
===================================================================
--- src/sas/sasgui/perspectives/calculator/model_editor.py	(revision a08b89bdf5a13632196725c27a97760f06d09e9c)
+++ src/sas/sasgui/perspectives/calculator/model_editor.py	(revision ddbac6633a1e7ec42b99bb39f46b9889ccf26084)
@@ -5,9 +5,9 @@
 function of y (usually the intensity).  It also provides a drop down of
 standard available math functions.  Finally a full python editor panel for
-complete customizatin is provided.
-
-:TODO the writiong of the file and name checking (and maybe some other
-funtions?) should be moved to a computational module which could be called
-fropm a python script.  Basically one just needs to pass the name,
+complete customization is provided.
+
+:TODO the writing of the file and name checking (and maybe some other
+functions?) should be moved to a computational module which could be called
+from a python script.  Basically one just needs to pass the name,
 description text and function text (or in the case of the composite editor
 the names of the first and second model and the operator to be used).
@@ -61,5 +61,5 @@
     """
     Dialog for easy custom composite models.  Provides a wx.Dialog panel
     to choose two existing models (including pre-existing custom models which
     may themselves be composite models) as well as an operation on those models
     (add or multiply) the resulting model will add a scale parameter for summed
@@ -380,5 +380,5 @@
             color = 'blue'
         except:
-            msg = "Easy Custom Sum/Multipy: Error occurred..."
+            msg = "Easy Sum/Multipy Plugin: Error occurred..."
             info = 'Error'
             color = 'red'
@@ -501,5 +501,5 @@
         self.factor = factor
         self._operator = operator
-        self.explanation = "  Custom Model = %s %s (model1 %s model2)\n" % \
+        self.explanation = "  Plugin Model = %s %s (model1 %s model2)\n" % \
                            (self.factor, f_oper, self._operator)
         self.explanationctr.SetLabel(self.explanation)
@@ -617,5 +617,5 @@
 class EditorPanel(wx.ScrolledWindow):
     """
-    Custom model function editor
+    Simple Plugin Model function editor
     """
     def __init__(self, parent, base, path, title, *args, **kwds):
@@ -652,5 +652,7 @@
         self.msg_sizer = None
         self.warning = ""
-        self._description = "New Custom Model"
+        #This does not seem to be used anywhere so commenting out for now
+        #    -- PDB 2/26/17 
+        #self._description = "New Plugin Model"
         self.function_tcl = None
         self.math_combo = None
@@ -991,5 +993,5 @@
         else:
             self._notes = result
-            msg = "Successful! Please look for %s in Customized Models."%name
+            msg = "Successful! Please look for %s in Plugin Models."%name
             msg += "  " + self._notes
             info = 'Info'
@@ -1138,5 +1140,5 @@
     def on_help(self, event):
         """
         Bring up the Custom Model Editor Documentation whenever
         the HELP button is clicked.
 
@@ -1190,5 +1192,5 @@
         #self.Destroy()
 
 ## Templates for custom models
 
 CUSTOM_TEMPLATE = """
@@ -61,5 +61,5 @@
     """
     Dialog for easy custom composite models.  Provides a wx.Dialog panel
-    to choose two existing models (including pre-existing custom models which
+    to choose two existing models (including pre-existing Plugin Models which
     may themselves be composite models) as well as an operation on those models
     (add or multiply) the resulting model will add a scale parameter for summed
@@ -1138,5 +1140,5 @@
     def on_help(self, event):
         """
-        Bring up the Custom Model Editor Documentation whenever
+        Bring up the New Plugin Model Editor Documentation whenever
         the HELP button is clicked.
 
@@ -1190,5 +1192,5 @@
         #self.Destroy()
 
-## Templates for custom models
+## Templates for plugin models
 
 CUSTOM_TEMPLATE = """